import type { SeederOptions, Table } from '../../typings';
/**
 * seeder client
 * @public
 */
export default class Seeder {
    private options;
    /**
     * array of tables x rows x values
     * @internal
     */
    private inserts;
    /**
     * output path
     * @internal
     */
    private path;
    /**
     * your tables
     */
    tables: Table[];
    /**
     * create a new seeder
     * @param tables - array of table
     * @param options - seeder options
     * @example
     * new Seeder(tables, { directory: 'seeds' })
     */
    constructor(tables?: Table[], options?: SeederOptions);
    /**
     * load a new table and add to tables property
     * @param table - table
     */
    add(table: Table): void;
    /**
     * get a specific table
     * @param name - table name
     * @returns { Table | null }
     */
    get(name: string): Table | null;
    /**
     * generate seeder file
     * @param options - generate options
     */
    generate(options?: {
        format?: 'sql' | 'json';
    }): void;
    /**
     * check if table exist or not
     * @param name - table name
     * @returns { boolean }
     */
    has(name: string): boolean;
    /**
     * delete a table
     * @param name - table name
     * @returns { Table | null }
     */
    remove(name: string): Table | null;
    /**
     * delete all tables
     */
    reset(): void;
}
