import type Types from '../../typings';
export declare class Seeder implements Types.Seeder {
    private options;
    private inserts;
    private path;
    tables: Types.Table[];
    /**
     * @param tables
     * @param options
     * @example
     * const tables = [
     *  {
     *    name: 'company',
     *    rows: 40,
     *    unique: ['suffix', 'name'],
     *    columns: {
     *      suffix: faker.company.companySuffix,
     *      name: faker.company.companyName,
     *      description: faker.company.catchPhrase,
     *      site: faker.internet.url,
     *    }
     *  }
     * ]
     *
     * const seeder = new Seeder(tables, { directory: './data', truncate: true })
     */
    constructor(tables?: Types.Table[] | null, options?: Types.SeederOptions);
    /**
     * Add new table
     * @param param0
     * @returns
     * @example
     * seeder.add({
     *  name: 'company',
     *  rows: 40,
     *  uniques: ['suffix', 'name'],
     *  columns: {
     *    suffix: faker.company.companySuffix,
     *    name: faker.company.companyName,
     *    description: faker.company.catchPhrase,
     *    site: faker.internet.url,
     *  },
     * })
     */
    add(table: Types.Table): void;
    /**
     * Get a table
     * @param name
     * @returns
     */
    get(name: string): Types.Table | null;
    /**
     * Generate your sql file
     */
    generate(): void;
    /**
     * Check if table exist
     * @param name
     * @returns
     */
    has(name: string): boolean;
    /**
     * Remove table
     * @param name
     * @returns
     */
    remove(name: string): Types.Table | null;
    /**
     * Remove all tables
     */
    reset(): void;
}
