"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.Utils = void 0;
const tslib_1 = require("tslib");
const path_1 = (0, tslib_1.__importDefault)(require("path"));
const fs_1 = require("fs");
class Utils {
    /**
     * Contact sql files
     * @param paths
     * @returns
     * @example
     * Utils.contact('./path/to/directory')
     * Utils.contact('./path/to/directory', './path/to/file.sql', './path/to/other-file.sql')
     * Utils.contact('./path/to/file.sql', './path/to/other-file.sql')
     */
    static concat(...paths) {
        const results = ['BEGIN;'];
        paths.forEach((p) => {
            const to = path_1.default.join(process.cwd(), p);
            if (!(0, fs_1.existsSync)(to))
                throw Error(`${to} not exist`);
            if (!(0, fs_1.lstatSync)(to).isDirectory() && !(0, fs_1.lstatSync)(to).isFile())
                throw Error(`${to} is not a directory or file`);
            const directory = (0, fs_1.lstatSync)(to).isFile() ? path_1.default.dirname(to) : to;
            const files = (0, fs_1.lstatSync)(to).isFile() ? [path_1.default.basename(to)] : (0, fs_1.readdirSync)(to);
            files.forEach((file) => {
                if (!file.endsWith('.sql'))
                    return;
                const content = (0, fs_1.readFileSync)(path_1.default.join(directory, file), { encoding: 'utf-8', flag: 'r' });
                const result = content.replace(/(BEGIN|COMMIT|ROLLBACK);?/, '').trim();
                results.push(result);
            });
        });
        return [...results, 'COMMIT;'].join('\n\n');
    }
    /**
     * Get stringify value for sql
     * @param param0
     * @returns
     */
    static resolve({ value, literal }) {
        if (value !== null) {
            if (typeof value === 'number')
                return (value || 0) + '';
            if (typeof value === 'boolean')
                return value + '';
            if (typeof value === 'object')
                return `'${JSON.stringify(value).replace(/'/g, "''")}'`;
            return `'${value.replace(/'/g, "''")}'`;
        }
        else
            return literal + '';
    }
}
exports.Utils = Utils;
//# sourceMappingURL=Utils.js.map